@@ -316,9 +316,7 @@ class SimpleSAML_Metadata_SAMLBuilder {
 
 		$e->SingleLogoutService = self::createEndpoints($metadata->getEndpoints('SingleLogoutService'), FALSE);
 
-		if ($metadata->hasValue('NameIDFormat')) {
-			$e->NameIDFormat[] = $metadata->getString('NameIDFormat');
-		}
+		$e->NameIDFormat = $metadata->getArrayizeString('NameIDFormat', array());
 
 		$endpoints = $metadata->getEndpoints('AssertionConsumerService');
 		foreach ($metadata->getArrayizeString('AssertionConsumerService.artifact', array()) as $acs) {
@@ -371,9 +369,7 @@ class SimpleSAML_Metadata_SAMLBuilder {
 
 		$e->SingleLogoutService = self::createEndpoints($metadata->getEndpoints('SingleLogoutService'), FALSE);
 
-		if ($metadata->hasValue('NameIDFormat')) {
-			$e->NameIDFormat[] = $metadata->getString('NameIDFormat');
-		}
+		$e->NameIDFormat = $metadata->getArrayizeString('NameIDFormat', array());
 
 		$e->SingleSignOnService = self::createEndpoints($metadata->getEndpoints('SingleSignOnService'), FALSE);
 
@@ -405,9 +401,7 @@ class SimpleSAML_Metadata_SAMLBuilder {
 
 		$this->addCertificate($e, $metadata);
 
-		if ($metadata->hasValue('NameIDFormat')) {
-			$e->NameIDFormat[] = $metadata->getString('NameIDFormat');
-		}
+		$e->NameIDFormat = $metadata->getArrayizeString('NameIDFormat', array());
 
 		$endpoints = $metadata->getEndpoints('AssertionConsumerService');
 		foreach ($metadata->getArrayizeString('AssertionConsumerService.artifact', array()) as $acs) {
@@ -442,9 +436,7 @@ class SimpleSAML_Metadata_SAMLBuilder {
 
 		$this->addCertificate($e, $metadata);
 
-		if ($metadata->hasValue('NameIDFormat')) {
-			$e->NameIDFormat[] = $metadata->getString('NameIDFormat');
-		}
+		$e->NameIDFormat = $metadata->getArrayizeString('NameIDFormat', array());
 
 		$e->SingleSignOnService = self::createEndpoints($metadata->getEndpoints('SingleSignOnService'), FALSE);
 
@@ -464,7 +456,7 @@ class SimpleSAML_Metadata_SAMLBuilder {
 
 		$metadata = SimpleSAML_Configuration::loadFromArray($metadata, $metadata['entityid']);
 
-		$e = new SAMl2_AttributeAuthorityDescriptor();
+		$e = new SAML2_XML_md_AttributeAuthorityDescriptor();
 		$e->protocolSupportEnumeration = $metadata->getArray('protocols', array());
 
 		$this->addExtensions($metadata, $e);
@@ -473,9 +465,7 @@ class SimpleSAML_Metadata_SAMLBuilder {
 		$e->AttributeService = self::createEndpoints($metadata->getEndpoints('AttributeService'), FALSE);
 		$e->AssertionIDRequestService = self::createEndpoints($metadata->getEndpoints('AssertionIDRequestService'), FALSE);
 
-		foreach ($metadata->getArray('NameIDFormat', array()) as $format) {
-			$e->NameIDFormat[] = $metadata->getString('NameIDFormat');
-		}
+		$e->NameIDFormat = $metadata->getArrayizeString('NameIDFormat', array());
 
 		$this->entityDescriptor->RoleDescriptor[] = $e;
 	}
@@ -586,11 +576,19 @@ class SimpleSAML_Metadata_SAMLBuilder {
 	 */
 	private function addCertificate(SAML2_XML_md_RoleDescriptor $rd, SimpleSAML_Configuration $metadata) {
 
-		$certInfo = SimpleSAML_Utilities::loadPublicKey($metadata);
-		if ($certInfo !== NULL && array_key_exists('certData', $certInfo)) {
-			$certData = $certInfo['certData'];
-			$this->addX509KeyDescriptor($rd, 'signing', $certData);
-			$this->addX509KeyDescriptor($rd, 'encryption', $certData);
+		$keys = $metadata->getPublicKeys();
+		if ($keys !== NULL) {
+			foreach ($keys as $key) {
+				if ($key['type'] !== 'X509Certificate') {
+					continue;
+				}
+				if (!isset($key['signing']) || $key['signing'] === TRUE) {
+					$this->addX509KeyDescriptor($rd, 'signing', $key['X509Certificate']);
+				}
+				if (!isset($key['encryption']) || $key['encryption'] === TRUE) {
+					$this->addX509KeyDescriptor($rd, 'encryption', $key['X509Certificate']);
+				}
+			}
 		}
 
 		if ($metadata->hasValue('https.certData')) {
