@@ -86,7 +86,15 @@ class SimpleSAML_Metadata_SAMLParser {
 	 */
 	private $organizationURL = array();
 	
+
+	/**
+	 * This is an array of the Contact Persons of this entity.
+	 */
+	private $contacts = array();
+
+
 	private $scopes;
+	private $entityAttributes;
 	private $attributes;
 	private $tags;
 
@@ -131,8 +139,9 @@ class SimpleSAML_Metadata_SAMLParser {
 
 		/* Process Extensions element, if it exists. */
 		$ext = self::processExtensions($entityElement);
-		$this->scopes = $ext['scopes'];
+		$this->scopes = $ext['scope'];
 		$this->tags = $ext['tags'];
+		$this->entityAttributes = $ext['EntityAttributes'];
 
 		/* Look over the RoleDescriptors. */
 		foreach ($entityElement->RoleDescriptor as $child) {
@@ -149,6 +158,12 @@ class SimpleSAML_Metadata_SAMLParser {
 		if ($entityElement->Organization) {
 			$this->processOrganization($entityElement->Organization);
 		}
+
+		if(!empty($entityElement->ContactPerson)) {
+			foreach($entityElement->ContactPerson as $contact) {
+				$this->processContactPerson($contact);
+			}
+		}
 	}
 
 
@@ -161,7 +176,9 @@ class SimpleSAML_Metadata_SAMLParser {
 	public static function parseFile($file) {
 		$doc = new DOMDocument();
 
-		$res = $doc->load($file);
+		$data = SimpleSAML_Utilities::fetch($file);
+
+		$res = $doc->loadXML($data);
 		if($res !== TRUE) {
 			throw new Exception('Failed to read XML from file: ' . $file);
 		}
@@ -229,9 +246,10 @@ class SimpleSAML_Metadata_SAMLParser {
 
 		if ($file === NULL) throw new Exception('Cannot open file NULL. File name not specified.');
 
-		$doc = new DOMDocument();
+		$data = SimpleSAML_Utilities::fetch($file);
 
-		$res = $doc->load($file);
+		$doc = new DOMDocument();
+		$res = $doc->loadXML($data);
 		if($res !== TRUE) {
 			throw new Exception('Failed to read XML from file: ' . $file);
 		}
@@ -389,6 +407,11 @@ class SimpleSAML_Metadata_SAMLParser {
 			$ret['OrganizationURL'] = $this->organizationURL;
 		}
 
+		/*
+		 * Add contact metadata
+		 */
+		$ret['contacts'] = $this->contacts;
+
 		return $ret;
 	}
 
@@ -400,18 +423,23 @@ class SimpleSAML_Metadata_SAMLParser {
 	 * @param array $roleDescriptor  The parsed role desciptor.
 	 */
 	private function addExtensions(array &$metadata, array $roleDescriptor) {
-		assert('array_key_exists("scopes", $roleDescriptor)');
+		assert('array_key_exists("scope", $roleDescriptor)');
 		assert('array_key_exists("tags", $roleDescriptor)');
 
-		$scopes = array_merge($this->scopes, array_diff($roleDescriptor['scopes'], $this->scopes));
+		$scopes = array_merge($this->scopes, array_diff($roleDescriptor['scope'], $this->scopes));
 		if (!empty($scopes)) {
-			$metadata['scopes'] = $scopes;
+			$metadata['scope'] = $scopes;
 		}
 
 		$tags = array_merge($this->tags, array_diff($roleDescriptor['tags'], $this->tags));
 		if (!empty($tags)) {
 			$metadata['tags'] = $tags;
 		}
+		
+		if (!empty($this->entityAttributes)) {
+			$metadata['EntityAttributes'] = $this->entityAttributes;
+		}
+		
 	}
 
 
@@ -466,20 +494,9 @@ class SimpleSAML_Metadata_SAMLParser {
 			$ret['description'] = $spd['description'];
 		}
 
-		/* Add certificate data. Only the first valid certificate will be added. */
-		foreach($spd['keys'] as $key) {
-			if($key['type'] !== 'X509Certificate') {
-				continue;
-			}
-
-			$certData = base64_decode($key['X509Certificate']);
-			if($certData === FALSE) {
-				/* Empty/invalid certificate. */
-				continue;
-			}
-
-			$ret['certData'] = preg_replace('/\s+/', '', str_replace(array("\r", "\n"), '', $key['X509Certificate']));
-			break;
+		/* Add public keys. */
+		if (!empty($spd['keys'])) {
+			$ret['keys'] = $spd['keys'];
 		}
 
 		/* Add extensions. */
@@ -528,23 +545,9 @@ class SimpleSAML_Metadata_SAMLParser {
 		/* Find the ArtifactResolutionService endpoint. */
 		$ret['ArtifactResolutionService'] = $idp['ArtifactResolutionService'];
 
-		/* Add certificate to metadata. Only the first valid certificate will be added. */
-		$ret['certFingerprint'] = array();
-		foreach($idp['keys'] as $key) {
-			if($key['type'] !== 'X509Certificate') {
-				continue;
-			}
-
-			$certData = base64_decode($key['X509Certificate']);
-			if($certData === FALSE) {
-				/* Empty/invalid certificate. */
-				continue;
-			}
-
-			/* Add the certificate data to the metadata. Only the first certificate will be added. */
-			$ret['certData'] = preg_replace('/\s+/', '', str_replace(array("\r", "\n"), '', $key['X509Certificate']));
-			$ret['certFingerprint'][] = sha1($certData);
-			break;
+		/* Add public keys. */
+		if (!empty($idp['keys'])) {
+			$ret['keys'] = $idp['keys'];
 		}
 
 		/* Add extensions. */
@@ -618,20 +621,9 @@ class SimpleSAML_Metadata_SAMLParser {
 			$ret['description'] = $spd['description'];
 		}
 
-		/* Add certificate data. Only the first valid certificate will be added. */
-		foreach($spd['keys'] as $key) {
-			if($key['type'] !== 'X509Certificate') {
-				continue;
-			}
-
-			$certData = base64_decode($key['X509Certificate']);
-			if($certData === FALSE) {
-				/* Empty/invalid certificate. */
-				continue;
-			}
-
-			$ret['certData'] = preg_replace('/\s+/', '', str_replace(array("\r", "\n"), '', $key['X509Certificate']));
-			break;
+		/* Add public keys. */
+		if (!empty($spd['keys'])) {
+			$ret['keys'] = $spd['keys'];
 		}
 
 
@@ -694,23 +686,9 @@ class SimpleSAML_Metadata_SAMLParser {
 		$ret['ArtifactResolutionService'] = $idp['ArtifactResolutionService'];
 
 
-		/* Add certificate to metadata. Only the first valid certificate will be added. */
-		$ret['certFingerprint'] = array();
-		foreach($idp['keys'] as $key) {
-			if($key['type'] !== 'X509Certificate') {
-				continue;
-			}
-
-			$certData = base64_decode($key['X509Certificate']);
-			if($certData === FALSE) {
-				/* Empty/invalid certificate. */
-				continue;
-			}
-
-			/* Add the certificate data to the metadata. Only the first certificate will be added. */
-			$ret['certData'] = preg_replace('/\s+/', '', str_replace(array("\r", "\n"), '', $key['X509Certificate']));
-			$ret['certFingerprint'][] = sha1($certData);
-			break;
+		/* Add public keys. */
+		if (!empty($idp['keys'])) {
+			$ret['keys'] = $idp['keys'];
 		}
 
 		/* Add extensions. */
@@ -770,8 +748,9 @@ class SimpleSAML_Metadata_SAMLParser {
 		}
 
 		$ext = self::processExtensions($element);
-		$ret['scopes'] = $ext['scopes'];
+		$ret['scope'] = $ext['scope'];
 		$ret['tags'] = $ext['tags'];
+		$ret['EntityAttributes'] = $ext['EntityAttributes'];
 
 		return $ret;
 	}
@@ -891,20 +870,56 @@ class SimpleSAML_Metadata_SAMLParser {
 	private static function processExtensions($element) {
 
 		$ret = array(
-			'scopes' => array(),
+			'scope' => array(),
 			'tags' => array(),
+			'EntityAttributes' => array(),
 		);
 
 		foreach ($element->Extensions as $e) {
 
 			if ($e instanceof SAML2_XML_shibmd_Scope) {
-				$ret['scopes'][] = $e->scope;
+				$ret['scope'][] = $e->scope;
 				continue;
 			}
+			
+			// Entity Attributes are only allowed at entity level extensions
+			// and not at RoleDescriptor level
+			if ($element instanceof SAML2_XML_md_EntityDescriptor) {
+	
+				if ($e instanceof SAML2_XML_mdattr_EntityAttributes && !empty($e->children)) {
+
+					foreach($e->children AS $attr) {
+						
+						// Only saml:Attribute are currently supported here. The specifications also allows
+						// saml:Assertions, which more complex processing.
+						if ($attr instanceof SAML2_XML_saml_Attribute) {
+							if (empty($attr->Name) || empty($attr->AttributeValue)) continue;
+
+							// Attribute names that is not URI is prefixed as this: '{nameformat}name'
+							$name = $attr->Name;
+							if(empty($attr->NameFormat)) {
+								$name = '{' . SAML2_Const::NAMEFORMAT_UNSPECIFIED . '}' . $attr->Name;
+							} elseif ($attr->NameFormat !== 'urn:oasis:names:tc:SAML:2.0:attrname-format:uri') {
+								$name = '{' . $attr->NameFormat . '}' . $attr->Name;
+							}
+							
+							$values = array();
+							foreach($attr->AttributeValue AS $attrvalue) {
+								$values[] = $attrvalue->getString();
+							}
+
+							$ret['EntityAttributes'][$name] = $values;
+						}
+					}
+				}				
+			}
+			
+
 
 			if (!($e instanceof SAML2_XML_Chunk)) {
 				continue;
 			}
+			
 
 			if ($e->localName === 'Attribute' && $e->namespaceURI === SAML2_Const::NS_SAML) {
 				$attribute = $e->getXML();
@@ -924,7 +939,6 @@ class SimpleSAML_Metadata_SAMLParser {
 				}
 			}
 		}
-
 		return $ret;
 	}
 
@@ -941,6 +955,38 @@ class SimpleSAML_Metadata_SAMLParser {
 		$this->organizationURL = $element->OrganizationURL;
 	}
 
+	/**
+	 * Parse and process a ContactPerson element.
+	 *
+	 * @param SAML2_XML_md_ContactPerson $element  The ContactPerson element.
+	 */
+
+	private function processContactPerson(SAML2_XML_md_ContactPerson $element) {
+
+		$contactPerson = array();
+		if(!empty($element->contactType)) {
+			$contactPerson['contactType'] = $element->contactType;
+		}
+		if(!empty($element->Company)) {
+			$contactPerson['company'] = $element->Company;
+		}
+		if(!empty($element->GivenName)) {
+			$contactPerson['givenName'] = $element->GivenName;
+		}
+		if(!empty($element->SurName)) {
+			$contactPerson['surName'] = $element->SurName;
+		}
+		if(!empty($element->EmailAddress)) {
+			$contactPerson['emailAddress'] = $element->EmailAddress;
+		}
+		if(!empty($element->TelephoneNumber)) {
+			$contactPerson['telephoneNumber'] = $element->TelephoneNumber;
+		}
+		if(!empty($contactPerson)) {
+			$this->contacts[] = $contactPerson;
+		}
+	}
+
 
 	/**
 	 * This function parses AttributeConsumerService elements.
@@ -1169,16 +1215,21 @@ class SimpleSAML_Metadata_SAMLParser {
 		assert('is_string($fingerprint)');
 
 		$fingerprint = strtolower(str_replace(":", "", $fingerprint));
-
+		
+		$candidates = array();
 		foreach ($this->validators as $validator) {
 			foreach ($validator->getValidatingCertificates() as $cert) {
+
 				$fp = strtolower(sha1(base64_decode($cert)));
+				$candidates[] = $fp;
 				if ($fp === $fingerprint) {
 					return TRUE;
 				}
 			}
-		}
 
+
+		}
+		SimpleSAML_Logger::debug('Fingerprint was [' . $fingerprint . '] not one of [' . join(', ', $candidates). ']');
 		return FALSE;
 	}
 
