@@ -5,7 +5,7 @@
  *
  * @author Andreas Åkre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
  * @package simpleSAMLphp
- * @version $Id: Utilities.php 2754 2011-03-07 13:25:34Z olavmrk $
+ * @version $Id: Utilities.php 2856 2011-05-27 10:39:52Z olavmrk $
  */
 class SimpleSAML_Utilities {
 
@@ -906,8 +906,8 @@ class SimpleSAML_Utilities {
 		assert('is_int($length)');
 
 		if($fp === NULL) {
-			if (file_exists('/dev/urandom')) {
-				$fp = fopen('/dev/urandom', 'rb');
+			if (@file_exists('/dev/urandom')) {
+				$fp = @fopen('/dev/urandom', 'rb');
 			} else {
 				$fp = FALSE;
 			}
