@@ -5,7 +5,7 @@
  *
  * @author Andreas Åkre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
  * @package simpleSAMLphp
- * @version $Id: Template.php 2183 2010-02-16 12:21:51Z olavmrk $
+ * @version $Id: Template.php 2582 2010-10-21 11:20:24Z olavmrk $
  */
 class SimpleSAML_XHTML_Template {
 
@@ -75,46 +75,38 @@ class SimpleSAML_XHTML_Template {
 	 */
 	public function setLanguage($language) {
 		$this->language = $language;
-		// setcookie ( string $name [, string $value [, int $expire [, string $path [, string $domain [, bool $secure [, bool $httponly ]]]]]] )
-		// time()+60*60*24*900 expires 900 days from now.
-		if (!headers_sent()) {
-			setcookie('language', $language, time()+60*60*24*900, '/');
-		}
+		SimpleSAML_XHTML_Template::setLanguageCookie($language);
 	}
 
 	/**
 	 * getLanguage() will return the language selected by the user, or the default language
-	 * This function first looks for a cached language code, 
+	 * This function first looks for a cached language code,
 	 * then checks for a language cookie,
 	 * then it tries to calculate the preferred language from HTTP headers.
 	 * Last it returns the default language.
-	 */	
-	public function getLanguage($checkHTTP = TRUE, $defaultFallback = TRUE) {
-		
+	 */
+	public function getLanguage() {
+
 		// Language is set in object
 		if (isset($this->language)) {
 			return $this->language;
 		}
 
 		// Language is provided in a stored COOKIE
-		if (isset($_COOKIE['language'])) {
-			$this->language = $_COOKIE['language'];
-			return $this->language;
+		$languageCookie = SimpleSAML_XHTML_Template::getLanguageCookie();
+		if ($languageCookie !== NULL) {
+			$this->language = $languageCookie;
+			return $languageCookie;
 		}
-		
-		if ($checkHTTP) {
-			/* Check if we can find a good language from the Accept-Language http header. */
-			$httpLanguage = $this->getHTTPLanguage();
-			if ($httpLanguage !== NULL) {
-				return $httpLanguage;
-			}
+
+		/* Check if we can find a good language from the Accept-Language http header. */
+		$httpLanguage = $this->getHTTPLanguage();
+		if ($httpLanguage !== NULL) {
+			return $httpLanguage;
 		}
 
 		// Language is not set, and we get the default language from the configuration.
-		if ($defaultFallback) 
-			return $this->getDefaultLanguage();
-			
-		return NULL;
+		return $this->getDefaultLanguage();
 	}
 
 
@@ -163,13 +155,7 @@ class SimpleSAML_XHTML_Template {
 		return $bestLanguage;
 	}
 
-	/**
-	 * Returns the language base (from configuration)
-	 */
-	private function getBaseLanguage() {
-		return 'en';
-	}
-	
+
 	/**
 	 * Returns the language default (from configuration)
 	 */
@@ -293,10 +279,9 @@ class SimpleSAML_XHTML_Template {
 			return $translations[$default_language];
 		}
 
-		/* Look up translation of tag in the base language. */
-		$base_language = $this->getBaseLanguage();
-		if(array_key_exists($base_language, $translations)) {
-			return $translations[$base_language];
+		/* Check for english translation. */
+		if(array_key_exists('en', $translations)) {
+			return $translations['en'];
 		}
 
 		/* Pick the first translation available. */
@@ -310,6 +295,38 @@ class SimpleSAML_XHTML_Template {
 	}
 
 
+	/**
+	 * Translate a attribute name.
+	 *
+	 * @param string $name  The attribute name.
+	 * @return string  The translated attribute name, or the original attribute name if no translation was found.
+	 */
+	public function getAttributeTranslation($name) {
+
+		/* Normalize attribute name. */
+		$normName = strtolower($name);
+		$normName = str_replace(":", "_", $normName);
+
+		/* Check for an extra dictionary. */
+		$extraDict = $this->configuration->getString('attributes.extradictionary', NULL);
+		if ($extraDict !== NULL) {
+			$dict = $this->getDictionary($extraDict);
+			if (array_key_exists($normName, $dict)) {
+				return $this->getTranslation($dict[$normName]);
+			}
+		}
+
+		/* Search the default attribute dictionary. */
+		$dict = $this->getDictionary('attributes');
+		if (array_key_exists('attribute_' . $normName, $dict)) {
+			return $this->getTranslation($dict['attribute_' . $normName]);
+		}
+
+		/* No translations found. */
+		return $name;
+	}
+
+
 	/**
 	 * Translate a tag into the current language, with a fallback to english.
 	 *
@@ -399,7 +416,7 @@ class SimpleSAML_XHTML_Template {
 	public function includeInlineTranslation($tag, $translation) {
 		
 		if (is_string($translation)) {
-			$translation = array($this->getBaseLanguage() => $translation);
+			$translation = array('en' => $translation);
 		} elseif (!is_array($translation)) {
 			throw new Exception("Inline translation should be string or array. Is " . gettype($translation) . " now!");
 		}
@@ -615,6 +632,35 @@ class SimpleSAML_XHTML_Template {
 		throw new Exception($error);
 	}
 
+
+	/**
+	 * Retrieve the user-selected language from a cookie.
+	 *
+	 * @return string|NULL  The language, or NULL if unset.
+	 */
+	public static function getLanguageCookie() {
+
+		if (!isset($_COOKIE['language'])) {
+			return NULL;
+		}
+		return (string)$_COOKIE['language'];
+	}
+
+
+	/**
+	 * Set the user-selected language in a cookie.
+	 *
+	 * @param string $language  The language.
+	 */
+	public static function setLanguageCookie($language) {
+		assert('is_string($language)');
+
+		if (headers_sent()) {
+			return;
+		}
+		setcookie('language', $language, time()+60*60*24*900, '/');
+	}
+
 }
 
 ?>
